@@ -46,6 +46,23 @@ public:
 
 }; //Apollo21xx
 
+#ifdef APDK_APOLLO21XX
+//! Apollo21xxProxy
+/*!
+******************************************************************************/
+class Apollo21xxProxy : public PrinterProxy
+{
+public:
+    Apollo21xxProxy() : PrinterProxy(
+        "AP21xx",                   // family name
+        "P-2000U\0"                             // Apollo P2000U
+		) {m_iPrinterType = eAP21xx;}
+    inline Printer* CreatePrinter(SystemServices* pSS) const { return new Apollo21xx(pSS); }
+	inline PRINTER_TYPE GetPrinterType() const { return eAP21xx;}
+	inline unsigned int GetModelBit() const { return 0x2000;}
+};
+#endif
+
 APDK_END_NAMESPACE
 
 #endif // APDK_APOLLO21xx_H
