@@ -41,24 +41,6 @@ APDK_BEGIN_NAMESPACE
 
 extern uint32_t ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
 extern uint32_t ulMapVOLTAIRE_CCM_CMY[ 9 * 9 * 9 ];
-
-//! DJ540Proxy
-/*!
-******************************************************************************/
-static class DJ540Proxy : public PrinterProxy
-{
-public:
-    DJ540Proxy() : PrinterProxy(
-        "DJ540",                    // family name
-        "DESKJET 540\0"                         // DeskJet 540
-#ifdef APDK_MLC_PRINTER
-        "OfficeJet Series 3\0"                  // OfficeJet Series 300
-#endif
-    ) {}
-    inline Printer* CreatePrinter(SystemServices* pSS) const { return new DJ540(pSS); }
-} DJ540Proxy;
-
-
 //
 // ** DJ540:Printer CLASS **
 //
