@@ -44,23 +44,6 @@ extern uint32_t ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
 extern uint32_t ulMapVOLTAIRE_CCM_CMY[ 9 * 9 * 9 ];
 
 
-//! DJ630Proxy
-/*!
-******************************************************************************/
-static class DJ630Proxy : public PrinterProxy
-{
-public:
-    DJ630Proxy() : PrinterProxy(
-        "DJ630",                    // family name
-        "DESKJET 63\0"                                  // DeskJet 63x Series
-        "DESKJET 65\0"                                  // DeskJet 65x Series
-#ifdef APDK_MLC_PRINTER
-#endif
-    ) {}
-    inline Printer* CreatePrinter(SystemServices* pSS) const { return new DJ630(pSS); }
-} DJ630Proxy;
-
-
 DJ630::DJ630(SystemServices* pSS, BOOL proto)
     : Printer(pSS, NUM_DJ6XX_FONTS,proto)
 {
@@ -272,8 +255,10 @@ Mode630BestGrayK::Mode630BestGrayK()
 {
    theQuality = qualityPresentation;
    pmQuality = QUALITY_BEST;
-   BaseResX = BaseResY = 600;
-   ResolutionX[0] = ResolutionY[0] = 600;
+   BaseResX = 600;
+   BaseResY = 600;
+   ResolutionX[0] = 600;
+   ResolutionY[0] = 600;
 }
 #endif // APDK_EXTENDED_MEDIASIZE
 
