@@ -31,9 +31,11 @@
 
 #include "config.h"
 
+#include "global_types.h"
+
 APDK_BEGIN_NAMESPACE
 
-unsigned long ulMapVENICE_HB_KCMY[ 9*9*9 ]=
+uint32_t ulMapVENICE_HB_KCMY[ 9*9*9 ]=
 {
 4074819328UL, 2530213376UL, 1420754432UL,  764542464UL,  477822464UL,  258866688UL,
  124255744UL,   23264768UL,    6422016UL, 4268472064UL, 2576481792UL, 1451818496UL,
@@ -175,7 +177,7 @@ unsigned long ulMapVENICE_HB_KCMY[ 9*9*9 ]=
 //   }
 
 
-unsigned long ulMapVENICE_Binary_KCMY[ 9*9*9 ]=
+uint32_t ulMapVENICE_Binary_KCMY[ 9*9*9 ]=
 {
 1819176648UL,   64158794UL,   80805158UL,   80215318UL,   62389519UL,   61406730UL,
   60292615UL,   42401028UL,    7601920UL, 4230922301UL,  571406681UL,  160889651UL,
