@@ -48,7 +48,7 @@ public:
     DRIVER_ERROR VerifyPenInfo ();
 //    DRIVER_ERROR ParsePenInfo (PEN_TYPE& ePen, BOOL QueryPrinter = TRUE);
     virtual PEN_TYPE DefaultPenSet();
-
+	inline virtual BOOL SupportSeparateBlack() {return FALSE;}
     virtual BOOL UseGUIMode (PrintMode* pPrintMode);
     PAPER_SIZE    MandatoryPaperSize ();
     virtual BOOL FullBleedCapable (PAPER_SIZE ps, FullbleedType  *fbType, float *xOverSpray, float *yOverSpray,
@@ -86,6 +86,12 @@ public:
     PSP100Mode ();
 }; //PSP100Mode
 
+class PSP100NormalMode : public PrintMode
+{
+public:
+    PSP100NormalMode ();
+}; //PSP100NormalMode
+
 #ifdef APDK_EXTENDED_MEDIASIZE
 //PSP1002400Mode
 /*
