@@ -130,6 +130,10 @@ DJ600Proxy DeviceRegistry::s_DJ600Proxy;
 DJ540Proxy DeviceRegistry::s_DJ540Proxy;
 #endif
 
+#ifdef APDK_DJ400
+DJ400Proxy DeviceRegistry::s_DJ400Proxy;
+#endif
+
 #ifdef APDK_DJ350
 DJ350Proxy DeviceRegistry::s_DJ350Proxy;
 #endif
