@@ -28,18 +28,11 @@
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 \*****************************************************************************/
 
-
-#ifdef APDK_PROTO
-#include "header.h"
-#include "io_defs.h"
-#include "../debug/script.h"
-#else
 #include "header.h"
 #include "io_defs.h"
 #ifdef APDK_CAPTURE
 #include "script.h"
 #endif // APDK_CAPTURE
-#endif
 
 APDK_BEGIN_NAMESPACE
 
@@ -53,7 +46,7 @@ Check constructor_error before continuing.
 */
 SystemServices::SystemServices()
     : constructor_error(NO_ERROR),
-#if defined(APDK_CAPTURE) || defined(APDK_PROTO)
+#if defined(APDK_CAPTURE)
     pScripter(NULL),
     Capturing(FALSE),
 #endif
@@ -62,11 +55,8 @@ SystemServices::SystemServices()
 
     strModel[0] = strPens[0] = '\0';
     VIPVersion = 0;
-#ifdef APDK_PROTO
-    DR = new ProtoRegistry();
-#else
+
     DR = new DeviceRegistry();
-#endif
     // DR can't fail
 
     IOMode.bDevID=FALSE;
@@ -84,7 +74,7 @@ SystemServices::~SystemServices()
 
     delete DR;
 
-#if defined(APDK_CAPTURE) || defined(APDK_PROTO)
+#if defined(APDK_CAPTURE)
     if (pScripter)
         delete pScripter;
 #endif
@@ -126,8 +116,10 @@ BOOL SystemServices::PrinterIsAlive()
     return (DEVICE_IS_OK(status_reg));
 }
 
-// Same as host-supplied FreeMem, with extra safety check
-// for null pointer.
+/*!
+ Same as host-supplied FreeMem, with extra safety check
+ for null pointer.
+*/
 DRIVER_ERROR SystemServices::FreeMemory(void *ptr)
 {
     if (ptr == NULL)
@@ -140,6 +132,9 @@ DRIVER_ERROR SystemServices::FreeMemory(void *ptr)
 }
 
 
+/*!
+This method tries to get the device id back from the printer and does some basic verification.
+*/
 DRIVER_ERROR SystemServices::GetDeviceID(BYTE* strID, int iSize, BOOL bQuery)
 {
 
